==> ez-constructs-0.0.19.tar.gz: ez-constructs-0.0.19/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "ez-constructs",
    "version": "0.0.19",
    "description": "ez-constructs",
    "license": "Apache-2.0",
    "url": "https://github.com/SavvyTools/ez-constructs.git",
    "long_description_content_type": "text/markdown",
    "author": "Biju Joseph<biju.joseph@semanticbits.com>",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/SavvyTools/ez-constructs.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "ez-constructs",
        "ez-constructs._jsii"
    ],
    "package_data": {
        "ez-constructs._jsii": [
            "ez-constructs@0.0.19.jsii.tgz"
        ],
        "ez-constructs": [
            "py.typed"
        ]
    },
    "python_requires": "~=3.7",
    "install_requires": [
        "aws-cdk-lib>=2.11.0, <3.0.0",
        "cdk-nag>=2.12.28, <3.0.0",
        "constructs>=10.0.5, <11.0.0",
        "jsii>=1.59.0, <2.0.0",
        "publication>=0.0.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Typing :: Typed",
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved"
    ],
    "scripts": []
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)

==> ez-constructs-0.0.20.tar.gz: ez-constructs-0.0.20/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "ez-constructs",
    "version": "0.0.20",
    "description": "ez-constructs",
    "license": "Apache-2.0",
    "url": "https://github.com/SavvyTools/ez-constructs.git",
    "long_description_content_type": "text/markdown",
    "author": "Biju Joseph<biju.joseph@semanticbits.com>",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/SavvyTools/ez-constructs.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "ez_constructs",
        "ez_constructs._jsii"
    ],
    "package_data": {
        "ez_constructs._jsii": [
            "ez-constructs@0.0.20.jsii.tgz"
        ],
        "ez_constructs": [
            "py.typed"
        ]
    },
    "python_requires": "~=3.7",
    "install_requires": [
        "aws-cdk-lib>=2.11.0, <3.0.0",
        "cdk-nag>=2.12.28, <3.0.0",
        "constructs>=10.0.5, <11.0.0",
        "jsii>=1.59.0, <2.0.0",
        "publication>=0.0.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Typing :: Typed",
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved"
    ],
    "scripts": []
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)
